Trait persistent::PersistentInto
[−]
[src]
pub trait PersistentInto<T> {
fn persistent_into(self) -> T;
}Helper trait for overloading the constructors of Read/Write/State.
This is an implementation detail, and should not be used for any other
purpose.
For example, this trait lets you construct a Read<T> from either a T or
an Arc<T>.
Required Methods
fn persistent_into(self) -> T
Convert self into a value of type T.